<?php

namespace Drupal\tone\Plugin\ToneIdentity;

use Drupal\tone\IdentityPluginBase;
use Drupal\tone\ToneInterface;

/**
 * Plugin implementation of the tone_identity.
 *
 * @ToneIdentity(
 *   id = "tone_entity_uuid",
 *   label = @Translation("Entity UUID"),
 *   description = @Translation("Uses the tone entity UUID, the bundle id and the view mode in clear text to generate the CSS selector. Useful during development since this mode makes it easy to correlate selectors to entities.")
 * )
 */
class EntityUuid extends IdentityPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getIdentifier(ToneInterface $entity, string $view_mode): string {
    $viewModeSanitized = strtolower(preg_replace('/[^a-z0-9]/i', '-', $view_mode));
    return implode('--', [$entity->uuid(), $viewModeSanitized]);
  }

  /**
   * {@inheritdoc}
   */
  public function getAttributes(ToneInterface $entity, string $view_mode): array {
    $identifier = $this->getIdentifier($entity, $view_mode);
    $name = $this->getName($entity);
    return [
      "data-${name}" => $identifier,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getSelector(ToneInterface $entity, string $view_mode): string {
    $identifier = $this->getIdentifier($entity, $view_mode);
    $name = $this->getName($entity);
    $parentSelector = '[data-' . $name . '="' . $identifier . '"]';

    /** @var \Drupal\tone\ToneTypeInterface $toneType */
    $toneType = $entity->bundle->entity;

    // Replace parent selector into tone type selector template.
    return str_replace('&', $parentSelector, $toneType->getSelector());
  }

  /**
   * Return data attribute prefix for given entity.
   */
  protected function getName(ToneInterface $entity): string {
    $bundleSanitized = strtolower(preg_replace('/[^a-z0-9]/i', '-', $entity->bundle()));
    return implode('--', ['tone', $bundleSanitized]);
  }

}
