<?php

namespace Drupal\tone;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining a tone type config entity.
 */
interface ToneTypeInterface extends ConfigEntityInterface {

  /**
   * Returns the CSS selector.
   */
  public function getSelector(): string;

  /**
   * Returns the identity plugin instance.
   */
  public function getIdentity(): IdentityInterface;

  /**
   * Returns the identity plugin ID.
   */
  public function getIdentityId(): string;

  /**
   * Returs the identity plugin configuration.
   */
  public function getIdentityConfiguration(): array;

  /**
   * Returns the renderer plugin instance.
   */
  public function getRenderer(): RendererInterface;

  /**
   * Returns the renderer plugin ID.
   */
  public function getRendererId(): string;

  /**
   * Returns the renderer plugin configuration.
   */
  public function getRendererConfiguration(): array;

  /**
   * Returns true if an attachment store is configured on this tone type.
   */
  public function hasAttachmentStore(): bool;

  /**
   * Returns the attachment store.
   */
  public function getAttachmentStore(): AttachmentStoreInterface;

  /**
   * Returns the attachment strategy.
   */
  public function getAttachmentStrategy(): AttachmentStrategyInterface;

  /**
   * Returns the attachment strategy plugin ID.
   */
  public function getAttachmentStrategyId(): string;

  /**
   * Returns the attachment strategy plugin configuration.
   */
  public function getAttachmentStrategyConfiguration(): array;

}
